==> foundation-utils-2.0.16.tgz: package/src/number/common.ts <==
const Decimal = require('decimal');
// 加法
function NumAdd(a, b): Number {
  return Number(new Decimal(a).add(new Decimal(b)));
}
// 减法
function NumSub(a, b): Number {
  return Number(new Decimal(a).sub(new Decimal(b)));
}
// 乘法
function NumMul(a, b): Number {
  return Number(new Decimal(a).mul(new Decimal(b)));
}
// 除法
function NumDiv(a, b): Number {
  return Number(new Decimal(a).div(new Decimal(b)));
}

/**
 * 千分位格式化
 * @param num 100000
 * @returns 100,100
 */
function Thousands(num: number | string): string {
  if (!num || isNaN(Number(num))) return num + "";
  let decimal;
  let integer = num;
  if (String(num).indexOf('.') > -1) {
    integer = String(num).split('.')[0];
    decimal = String(num).split('.')[1];
  }
  if (String(integer).length <= 3) return num + "";
  // 千分位符
  let reg = /\d{1,3}(?=(\d{3})+$)/g;
  if (decimal) return `${(integer + '').replace(reg, '$&,')}.${decimal}`;
  return (integer + '').replace(reg, '$&,');
}

/**
 * 千分位格式化 带小数
 * 例：ThousandsFloat(5000, 2)  =>5,000.00
 * @param num :5000
 * @param decimal :2 (小数位 0-20)
 * @returns  5,000.00
 */
function ThousandsFloat(num: number | string, decimal: number) {
  if (!num) {
    return "0.00";
  }
  decimal = decimal > 0 && decimal <= 20 ? decimal : 2;
  const sStr = parseFloat(String(num).replace(/[^\d.-]/g, "")).toFixed(decimal);
  return Thousands(sStr);
}

/**
 * 金额单位格式化
 * @param value 格式化对象
 * @param baseUnit 格式单位 (例如：100，1000，10000)
 * @param NaNText 错误展示文案
 * @returns
 */
function MoneyUnitSwitch(num: number, baseUnit: number, NaNText?: string) {
  if (isNaN(num)) {
    return NaNText || 0;
  }
  let float = (num / baseUnit).toFixed(2);
  return Thousands(float);
}

/**
 * num为传入的值，n为保留的小数位 n 默认保留2位小数
 * @param num
 * @param decimal 小数位 （ 默认值：2）
 * @returns
 */
function FormatFloat(num: number, decimal?: number) {
  let f = parseFloat(String(num));
  if (isNaN(f)) {
    return 0;
  }
  decimal = decimal || 2;
  return f.toFixed(decimal);
}
/**
 * 获取字符串中的正整数
 * @param {string} value
 * @returns
 */
function FilterNumber(value: string) {
  let str = value.replace(/[^\d]/g, '');
  return Number(str);
}

export {
  NumAdd,
  NumSub,
  NumMul,
  NumDiv,
  Thousands,
  ThousandsFloat,
  MoneyUnitSwitch,
  FormatFloat,
  FilterNumber
}

==> foundation-utils-2.0.19.tgz: package/src/number/common.ts <==
const Decimal = require('decimal');
// 加法
function NumAdd(a: number | string, b: number | string): Number {
  return Number(new Decimal(a).add(new Decimal(b)));
}
// 减法
function NumSub(a: number | string, b: number | string): Number {
  return Number(new Decimal(a).sub(new Decimal(b)));
}
// 乘法
function NumMul(a: number | string, b: number | string): Number {
  return Number(new Decimal(a).mul(new Decimal(b)));
}
// 除法
function NumDiv(a: number | string, b: number | string): Number {
  return Number(new Decimal(a).div(new Decimal(b)));
}

/**
 * 千分位格式化
 * @param num 100000
 * @returns 100,100
 */
function Thousands(num: number | string): string {
  if (!num || isNaN(Number(num))) return num + "";
  let decimal;
  let integer = num;
  if (String(num).indexOf('.') > -1) {
    integer = String(num).split('.')[0];
    decimal = String(num).split('.')[1];
  }
  if (String(integer).length <= 3) return num + "";
  // 千分位符
  let reg = /\d{1,3}(?=(\d{3})+$)/g;
  if (decimal) return `${(integer + '').replace(reg, '$&,')}.${decimal}`;
  return (integer + '').replace(reg, '$&,');
}

/**
 * 千分位格式化 带小数
 * 例：ThousandsFloat(5000, 2)  =>5,000.00
 * @param num :5000
 * @param decimal :2 (小数位 0-20)
 * @returns  5,000.00
 */
function ThousandsFloat(num: number | string, decimal: number) {
  if (!num) {
    return "0.00";
  }
  decimal = decimal > 0 && decimal <= 20 ? decimal : 2;
  const sStr = parseFloat(String(num).replace(/[^\d.-]/g, "")).toFixed(decimal);
  return Thousands(sStr);
}

/**
 * 金额单位格式化
 * @param value 格式化对象
 * @param baseUnit 格式单位 (例如：100，1000，10000)
 * @param NaNText 错误展示文案
 * @returns
 */
function MoneyUnitSwitch(num: number, baseUnit: number, NaNText?: string) {
  if (isNaN(num)) {
    return NaNText || 0;
  }
  let float = (num / baseUnit).toFixed(2);
  return Thousands(float);
}

/**
 * num为传入的值，n为保留的小数位 n 默认保留2位小数
 * @param num
 * @param decimal 小数位 （ 默认值：2）
 * @returns
 */
function FormatFloat(num: number, decimal?: number) {
  let f = parseFloat(String(num));
  if (isNaN(f)) {
    return 0;
  }
  decimal = decimal || 2;
  return f.toFixed(decimal);
}
/**
 * 获取字符串中的正整数
 * @param {string} value
 * @returns
 */
function FilterNumber(value: string) {
  let str = value.replace(/[^\d]/g, '');
  return Number(str);
}

export {
  NumAdd,
  NumSub,
  NumMul,
  NumDiv,
  Thousands,
  ThousandsFloat,
  MoneyUnitSwitch,
  FormatFloat,
  FilterNumber
}
